summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMarco <marcoambrosini@icloud.com>2023-04-07 15:11:51 +0100
committerMarco <marcoambrosini@icloud.com>2023-04-18 06:35:39 +0100
commit8a25e0d2ae9836cbdf496a689428e828cdd70f09 (patch)
tree3eae08ebaf5c95582085b6630dc7781fb72525a9
parent0870a2656383c6b21ef169ba5a5c9568d343727b (diff)
Rename devicechecker into mediasettings
Signed-off-by: Marco <marcoambrosini@icloud.com>
-rw-r--r--src/App.vue6
-rw-r--r--src/FilesSidebarTabApp.vue6
-rw-r--r--src/PublicShareSidebar.vue6
-rw-r--r--src/components/ConversationSettings/ConversationSettingsDialog.vue14
-rw-r--r--src/components/MediaSettings/MediaSettings.vue (renamed from src/components/DeviceChecker/DeviceChecker.vue)34
-rw-r--r--src/components/TopBar/CallButton.vue14
6 files changed, 40 insertions, 40 deletions
diff --git a/src/App.vue b/src/App.vue
index 139e86732..68dbbeeea 100644
--- a/src/App.vue
+++ b/src/App.vue
@@ -30,7 +30,7 @@
</NcAppContent>
<RightSidebar :is-in-call="isInCall" />
<PreventUnload :when="warnLeaving || isSendingMessages" />
- <DeviceChecker :initialize-on-mounted="false" />
+ <MediaSettings :initialize-on-mounted="false" />
<UploadEditor />
<SettingsDialog />
<ConversationSettingsDialog />
@@ -50,8 +50,8 @@ import NcContent from '@nextcloud/vue/dist/Components/NcContent.js'
import isMobile from '@nextcloud/vue/dist/Mixins/isMobile.js'
import ConversationSettingsDialog from './components/ConversationSettings/ConversationSettingsDialog.vue'
-import DeviceChecker from './components/DeviceChecker/DeviceChecker.vue'
import LeftSidebar from './components/LeftSidebar/LeftSidebar.vue'
+import MediaSettings from './components/MediaSettings/MediaSettings.vue'
import RightSidebar from './components/RightSidebar/RightSidebar.vue'
import SettingsDialog from './components/SettingsDialog/SettingsDialog.vue'
import UploadEditor from './components/UploadEditor.vue'
@@ -82,7 +82,7 @@ export default {
UploadEditor,
SettingsDialog,
ConversationSettingsDialog,
- DeviceChecker,
+ MediaSettings,
},
mixins: [
diff --git a/src/FilesSidebarTabApp.vue b/src/FilesSidebarTabApp.vue
index 5b4254af7..acad204ee 100644
--- a/src/FilesSidebarTabApp.vue
+++ b/src/FilesSidebarTabApp.vue
@@ -42,7 +42,7 @@
<CallButton class="call-button" />
<ChatView />
<UploadEditor />
- <DeviceChecker :initialize-on-mounted="false" />
+ <MediaSettings :initialize-on-mounted="false" />
</template>
</div>
</template>
@@ -56,7 +56,7 @@ import { loadState } from '@nextcloud/initial-state'
import NcButton from '@nextcloud/vue/dist/Components/NcButton.js'
import ChatView from './components/ChatView.vue'
-import DeviceChecker from './components/DeviceChecker/DeviceChecker.vue'
+import MediaSettings from './components/MediaSettings/MediaSettings.vue'
import CallButton from './components/TopBar/CallButton.vue'
import UploadEditor from './components/UploadEditor.vue'
@@ -81,7 +81,7 @@ export default {
CallButton,
ChatView,
UploadEditor,
- DeviceChecker,
+ MediaSettings,
NcButton,
},
diff --git a/src/PublicShareSidebar.vue b/src/PublicShareSidebar.vue
index 551e06b7e..ffaedab5e 100644
--- a/src/PublicShareSidebar.vue
+++ b/src/PublicShareSidebar.vue
@@ -46,7 +46,7 @@
<PreventUnload :when="warnLeaving" />
<CallButton class="call-button" />
<ChatView />
- <DeviceChecker :initialize-on-mounted="false" />
+ <MediaSettings :initialize-on-mounted="false" />
</template>
</aside>
</transition>
@@ -62,7 +62,7 @@ import NcButton from '@nextcloud/vue/dist/Components/NcButton.js'
import CallView from './components/CallView/CallView.vue'
import ChatView from './components/ChatView.vue'
-import DeviceChecker from './components/DeviceChecker/DeviceChecker.vue'
+import MediaSettings from './components/MediaSettings/MediaSettings.vue'
import CallButton from './components/TopBar/CallButton.vue'
import TopBar from './components/TopBar/TopBar.vue'
@@ -91,7 +91,7 @@ export default {
CallView,
ChatView,
PreventUnload,
- DeviceChecker,
+ MediaSettings,
TopBar,
},
diff --git a/src/components/DeviceChecker/DeviceChecker.vue b/src/components/MediaSettings/MediaSettings.vue
index ce889e14d..829497997 100644
--- a/src/components/DeviceChecker/DeviceChecker.vue
+++ b/src/components/MediaSettings/MediaSettings.vue
@@ -25,12 +25,12 @@
size="small"
:container="container"
@close="closeModal">
- <div class="device-checker">
- <h2 class="device-checker__title">
+ <div class="media-settings">
+ <h2 class="media-settings__title">
{{ t('spreed', 'Camera and microphone check') }}
</h2>
<!-- Preview -->
- <div class="device-checker__preview">
+ <div class="media-settings__preview">
<!-- eslint-disable-next-line -->
<video v-show="showVideo"
ref="video"
@@ -59,7 +59,7 @@
Toggle audio and video on and off before starting or joining
a call.
-->
- <div class="device-checker__call-preferences">
+ <div class="media-settings__call-preferences">
<!-- Audio toggle -->
<NcButton v-tooltip="audioButtonTooltip"
type="tertiary"
@@ -106,7 +106,7 @@
</div>
<!-- Device selection -->
- <div class="device-checker__device-selection">
+ <div class="media-settings__device-selection">
<NcButton v-if="!showDeviceSelection"
type="tertiary"
class="select-devices"
@@ -127,7 +127,7 @@
@update:deviceId="videoInputId = $event" />
</template>
</div>
- <NcCheckboxRadioSwitch :checked.sync="showDeviceChecker"
+ <NcCheckboxRadioSwitch :checked.sync="showMediaSettings"
class="checkbox">
<template v-if="canRecordingTakePlace">
{{ t('spreed', 'Always show this dialog before joining a call in this conversation. The dialog will always be shown when the call is being recorded.') }}
@@ -142,7 +142,7 @@
<p>{{ t('spreed', 'The call is being recorded.') }}</p>
</NcNoteCard>
- <div class="device-checker__call-buttons">
+ <div class="media-settings__call-buttons">
<!-- Silent call -->
<NcActions v-if="showSilentCallOption"
:container="container"
@@ -210,7 +210,7 @@ import BrowserStorage from '../../services/BrowserStorage.js'
import { localMediaModel } from '../../utils/webrtc/index.js'
export default {
- name: 'DeviceChecker',
+ name: 'MediaSettings',
directives: {
Tooltip,
@@ -247,7 +247,7 @@ export default {
audioOn: undefined,
videoOn: undefined,
blurOn: undefined,
- showDeviceChecker: true,
+ showMediaSettings: true,
silentCall: false,
}
},
@@ -347,11 +347,11 @@ export default {
}
},
- showDeviceChecker(newValue) {
+ showMediaSettings(newValue) {
if (newValue) {
- BrowserStorage.setItem('showDeviceChecker' + this.token, 'true')
+ BrowserStorage.setItem('showMediaSettings' + this.token, 'true')
} else {
- BrowserStorage.setItem('showDeviceChecker' + this.token, 'false')
+ BrowserStorage.setItem('showMediaSettings' + this.token, 'false')
}
},
@@ -373,13 +373,13 @@ export default {
},
mounted() {
- subscribe('talk:device-checker:show', this.showModal)
- subscribe('talk:device-checker:hide', this.closeModal)
+ subscribe('talk:media-settings:show', this.showModal)
+ subscribe('talk:media-settings:hide', this.closeModal)
},
beforeDestroy() {
- unsubscribe('talk:device-checker:show', this.showModal)
- unsubscribe('talk:device-checker:hide', this.closeModal)
+ unsubscribe('talk:media-settings:show', this.showModal)
+ unsubscribe('talk:media-settings:hide', this.closeModal)
},
methods: {
@@ -431,7 +431,7 @@ export default {
@include avatar-mixin(64px);
@include avatar-mixin(128px);
-.device-checker {
+.media-settings {
padding: 20px;
background-color: var(--color-main-background);
overflow-y: auto;
diff --git a/src/components/ConversationSettings/ConversationSettingsDialog.vue b/src/components/ConversationSettings/ConversationSettingsDialog.vue
index e28c4a3d8..adccf9d9d 100644
--- a/src/components/ConversationSettings/ConversationSettingsDialog.vue
+++ b/src/components/ConversationSettings/ConversationSettingsDialog.vue
@@ -38,7 +38,7 @@
<!-- Notifications settings and devices preview screen -->
<NcAppSettingsSection id="notifications"
:title="t('spreed', 'Personal')">
- <NcCheckboxRadioSwitch :checked.sync="showDeviceChecker"
+ <NcCheckboxRadioSwitch :checked.sync="showMediaSettings"
type="switch">
{{ t('spreed', 'Always show the device preview screen before joining a call in this conversation.') }}
</NcCheckboxRadioSwitch>
@@ -147,7 +147,7 @@ export default {
return {
showSettings: false,
matterbridgeEnabled: loadState('spreed', 'enable_matterbridge'),
- showDeviceChecker: false,
+ showMediaSettings: false,
}
},
@@ -210,9 +210,9 @@ export default {
},
watch: {
- showDeviceChecker(newValue) {
+ showMediaSettings(newValue) {
const browserValue = newValue ? 'true' : 'false'
- BrowserStorage.setItem('showDeviceChecker' + this.token, browserValue)
+ BrowserStorage.setItem('showMediaSettings' + this.token, browserValue)
},
},
@@ -221,10 +221,10 @@ export default {
subscribe('hide-conversation-settings', this.handleHideSettings)
/**
* Get the deviceChecker value from the browser storage.
*/
- this.showDeviceChecker = BrowserStorage.getItem('showDeviceChecker' + this.token) === null
- || BrowserStorage.getItem('showDeviceChecker' + this.token) === 'true'
+ this.showMediaSettings = BrowserStorage.getItem('showMediaSettings' + this.token) === null
+ || BrowserStorage.getItem('showMediaSettings' + this.token) === 'true'
},
methods: {
@@ -221,10 +221,10 @@ export default {
subscribe('hide-conversation-settings', this.handleHideSettings)
/**
- * Get the deviceChecker value from the browser storage.
+ * Get the MediaSettings value from the browser storage.
*/
diff --git a/src/components/TopBar/CallButton.vue b/src/components/TopBar/CallButton.vue
index 3a30ba8c6..191d034d8 100644
--- a/src/components/TopBar/CallButton.vue
+++ b/src/components/TopBar/CallButton.vue
@@ -128,7 +128,7 @@ export default {
props: {
/**
* Skips the device checker dialog and joins or starts the call
* upon clicking the button
*/
forceJoinCall: {
@@ -328,13 +328,13 @@ export default {
},
handleClick() {
- const shouldShowDeviceCheckerScreen = (BrowserStorage.getItem('showDeviceChecker' + this.token) === null
- || BrowserStorage.getItem('showDeviceChecker' + this.token) === 'true') && !this.forceJoinCall
- console.debug(shouldShowDeviceCheckerScreen)
- if (((this.isStartingRecording || this.isRecording) && !this.forceJoinCall) || shouldShowDeviceCheckerScreen) {
- emit('talk:device-checker:show')
+ const shouldShowMediaSettingsScreen = (BrowserStorage.getItem('showMediaSettings' + this.token) === null
+ || BrowserStorage.getItem('showMediaSettings' + this.token) === 'true') && !this.forceJoinCall
+ console.debug(shouldShowMediaSettingsScreen)
+ if (((this.isStartingRecording || this.isRecording) && !this.forceJoinCall) || shouldShowMediaSettingsScreen) {
+ emit('talk:media-settings:show')
} else {
- emit('talk:device-checker:hide')
+ emit('talk:media-settings:hide')
this.joinCall()
}
},
@@ -128,7 +128,7 @@ export default {
props: {
/**
- * Skips the device checker dialog and joins or starts the call
+ * Skips the media settings dialog and joins or starts the call
* upon clicking the button
*/